RequestClient class

Constructors

RequestClient({required RequestConfig config, List<Interceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request<T>(String url, {RequestType? method, dynamic data, Map<String, dynamic>? headers, Map<String, dynamic>? extra, bool showLoading = false}) Future<ApiResponse>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance RequestClient
no setter

Static Methods

init({required RequestConfig config, List<Interceptor>? interceptors}) Future<void>