RequestConfig class

Constructors

RequestConfig({String baseUrl = 'your_default_base_url'})

Properties

baseUrl String?
getter/setter pair
codeKey String
getter/setter pair
connectTimeOut int
getter/setter pair
dataKey String
getter/setter pair
enableLoginCodes List
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
loginOutCall InterceptorBack?
getter/setter pair
messageKey String
getter/setter pair
readTimeOut int
getter/setter pair
requestCall InterceptorRequestBack?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
successCode int
getter/setter pair
writeTimeOut int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance RequestConfig
no setter

Static Methods

init({required String baseUrl}) Future<void>